import React, { useEffect, useState } from 'react';
import { Button, Form, type FormProps, Input, message, Divider } from 'antd';
import { Card } from "antd";
import $ from 'jquery'
import { ClassManagerSite,FootText,WebsiteTitle,deceteMobile } from '../global.ts';
import { PasswordHash } from '../Module/PasswordCrypto.ts';
import './login.css';
import { Footer } from 'antd/lib/layout/layout';

type FieldType = {
    account?: string;
    password?: string;
    remember?: string;
};




const Login: React.FC = () => {

    const [messageApi, contextHolder] = message.useMessage();
    const [isRemember,setIsRemember] = useState(true);
    const [buttonLoading, setButtonLoading] = useState(false);
    const [isMobile, _setIsMobile] = useState(deceteMobile());

    const [errorCount,setErrorCount] = useState(0);

    const onFinish: FormProps<FieldType>["onFinish"] = (values) => {
        FormSumbit(values);
        console.log('Success:', values);
    };


    const onFinishFailed: FormProps<FieldType>["onFinishFailed"] = (errorInfo) => {
        console.log('Failed:', errorInfo);
    };

    function FormSumbit(values: any) {

        if(errorCount >= 5){
            messageApi.error("密码错误次数已达上限，请一分钟后再试");
            return;
        }


        setButtonLoading(true);
        var account: string = values.account;
        var passwd: string = values.password;
        var remember: string = isRemember.toString();

        $.ajax({
            type: "POST",
            url: ClassManagerSite + "/Server/user/login.php",
            data: {
                mode: 1,
                account: account,
                passwd: PasswordHash(passwd),
                remember: remember
            },
            success: function (data: any) {
                if (data == 0) {
                    window.location.href = "./";
                } else {
                    messageApi.error("登录失败");
                    setErrorCount(errorCount + 1);
                    if (errorCount + 1 >= 5) {
                        disableLogin();
                    }
                }
                setButtonLoading(false);
            },
            error: function (_data: any) {
                messageApi.error("登录失败");
                setButtonLoading(false);
            }
        });
    }


    function disableLogin(){
        messageApi.error("密码错误次数已达上限，请一分钟后再试");
        setTimeout(function(){
            setErrorCount(0);
        },6000);
    }

    useEffect(() => {
      
    });

    return(
    <div id="LoginArea">
        {contextHolder}
      { 
        <Card id="LoginCard" title={WebsiteTitle} size="default" hoverable>
    <Form
        name="basic"
        labelCol={{ span: 5 }}
        wrapperCol={{ span: 16 }}
        onFinish={onFinish}
        onFinishFailed={onFinishFailed}
        autoComplete="off"
    >
        <Form.Item<FieldType>
            label="账号"
            name="account"
            rules={[{ required: true, message: '请输入账号!'},
            {
                message:'请勿输入特殊字符',
                pattern:/^((?!\+|\.|\\|\/|:|\*|\?|<|>|\|| |'|%|@|#|&|\$|\^|&|\*).){1,20}$/ 
            }
            ]}
        >
            <Input maxLength={20}/>
        </Form.Item>

        <Form.Item<FieldType>
            label="密码"
            name="password"
            rules={[{ required: true, message: '请输入密码!' }]}
        >
            <Input.Password visibilityToggle  />
        </Form.Item>




        <Form.Item wrapperCol={(isMobile ? { offset: 0, span: 16 } : { offset: 5, span: 16 })}>
            <Button block type="primary" htmlType="submit" loading={buttonLoading}>
                登录
            </Button>
        </Form.Item>
    </Form>
    </Card>      
    }

            <Divider style={{ textAlign: 'center' }}>

                <Footer style={{ textAlign: 'center',backgroundColor: 'transparent' }}>
                    {FootText}
                </Footer>
    

            </Divider>

    </div>
    )
};

export default Login;