import { DownOutlined, InboxOutlined } from '@ant-design/icons';
import { Button, Card, Col, Dropdown, Flex, Form, InputNumber, InputNumberProps, MenuProps, message, Modal, Row, Slider, Space } from 'antd';
import React, { useState } from 'react';
import Img from "../../../IMG.jpg";
import Dragger from 'antd/lib/upload/Dragger';
import { ServerUrl, PostResult } from '../../../global';
import $ from 'jquery';
import { RequestDecode } from '../../../Module/RequestDecode';



const items: MenuProps['items'] = [
    {
        key: '1',
        label: (
            <a target="_blank" rel="noopener noreferrer" href="https://www.antgroup.com">
                1st menu item
            </a>
        ),
    },
    {
        key: '2',
        label: (
            <a target="_blank" rel="noopener noreferrer" href="https://www.luohanacademy.com">
                3rd menu item (disabled)
            </a>
        ),
        disabled: true,
    },
];

const normFile = (e: any) => {
    if (Array.isArray(e)) {
        return e;
    }
    return e && e.fileList;
};










const BugDetect: React.FC = () => {

    const [inputValue, setInputValue] = useState(0.50);
    const [imgOpen, setImgOpen] = useState(false);
    const [videoOpen, setVideoOpen] = useState(false);
    const [messageApi, contextHolder] = message.useMessage();


    const [form1] = Form.useForm();
    const [form2] = Form.useForm();
    const [imgButtonLoading, setImgButtonLoading] = useState(false);
    const [videoButtonLoading, setVideoButtonLoading] = useState(false);

    const [uploadImgUrl, setUploadImgUrl] = useState(Img);
    const [resultImgUrl, setResultImgUrl] = useState(Img);
    const [detectResult,setDetectResult] = useState("未知");

    function ImgUpload(values: any) {
        setImgButtonLoading(true);
        var formData = new FormData();
        var i: number = 0;
        if (values.files) {
            for (var file of values.files) {
                var convertedFile = new File([file.originFileObj], file.name);
                formData.append("files" + i, convertedFile, convertedFile.name);
                i++;
            }
        } else {
            messageApi.info("请上传文件");
            setImgButtonLoading(false);
            return;
        }

        setUploadImgUrl

        $.ajax({
            url: ServerUrl,
            type: "post",
            data: formData,
            cache: false,
            contentType: false,
            processData: false,
            success: function (data: any) {

                var result: PostResult =  RequestDecode(data);
                if(result.code == 200){
                    //var imgUrl = result.data;
                    //setResultImgUrl(imgUrl);
                    //setDetectResult(result.data);
                }
            },
            error: function (err: any) {
                messageApi.error("上传失败: " + err);
            },
        });



        setImgOpen(false);
        setImgButtonLoading(false);
        form1.resetFields();
    }


    function VideoUpload(values: any) {
        setVideoButtonLoading(true);
        var formData = new FormData();
        var i: number = 0;
        if (values.files) {
            for (var file of values.files) {
                var convertedFile = new File([file.originFileObj], file.name);
                formData.append("files" + i, convertedFile, convertedFile.name);
                i++;
            }
        } else {
            messageApi.info("请上传文件");
            setImgButtonLoading(false);
            return;
        }

        $.ajax({
            url: ServerUrl,
            type: "post",
            data: formData,
            cache: false,
            contentType: false,
            processData: false,
            success: function (data: any) {
                var result: PostResult = RequestDecode(data);

            },
            error: function (err: any) {
                messageApi.error("上传失败: " + err);
            },
        });

        setVideoOpen(false);
        setVideoButtonLoading(false);
    }


    const onChange: InputNumberProps['onChange'] = (value) => {
        if (Number.isNaN(value)) {
            return;
        }
        setInputValue(value as number);
    };

    return (
        <>
            <Flex gap="large" vertical style={{ height: "100%",margin:"10px" }}>

                <Card>
                <Row justify="space-between">
                    <Col span={6}>
                        <Card title="模型" >
                            <Dropdown menu={{ items }}>
                                <a onClick={(e) => e.preventDefault()}>
                                    <Space>
                                        best.omnx
                                        <DownOutlined />
                                    </Space>
                                </a>
                            </Dropdown>
                        </Card>
                    </Col>
                    <Col span={6}>
                        <Card title="IOU" >
                            <Row>
                                <Col span={6}> <InputNumber min={0} max={1} style={{ width: '100%' }} step={0.01} value={inputValue} onChange={onChange} /> </Col>
                                <Col span={1}> </Col>
                                <Col span={15}> <Slider min={0} max={1} style={{ width: '100%' }} step={0.01} onChange={onChange} value={typeof inputValue === 'number' ? inputValue : 0} /></Col>
                            </Row>

                        </Card>
                    </Col>
                    <Col span={6}>
                        <Card title="Conference">
                            <Row>
                                <Col span={6}> <InputNumber min={0} max={1} style={{ width: '100%' }} step={0.01} value={inputValue} onChange={onChange} /> </Col>
                                <Col span={1}> </Col>
                                <Col span={15}> <Slider min={0} max={1} style={{ width: '100%' }} step={0.01} onChange={onChange} value={typeof inputValue === 'number' ? inputValue : 0} /></Col>
                            </Row>
                        </Card>
                        
                    </Col>
                </Row>
                </Card>
                <Flex vertical>
                    <Row justify="space-between">
                        <Col span={14}>
                            <Card >
                                <Flex vertical gap="large" >
                                    <Flex vertical style={{ margin: "5% 2% 0 5%" }}>
                                        <img src={uploadImgUrl} style={{ height: "90%" }} />
                                    </Flex>
                                    <Row>
                                        <Col span={10}> <Button onClick={() => { setImgOpen(true) }}>图片检测</Button>  {/*<Button onClick={() => { setVideoOpen(true) }}>视频检测</Button>*/}</Col>                                            
                                    </Row>
                                </Flex>
                            </Card>
                        </Col>
                        <Col span={6}>
                            <Card title="检测结果" style={{ height: "100%" }}>
                                <img src={resultImgUrl} style={{ width: "100%" }} />
                                <Space />
                                <b>结果:</b>
                                <Space />
                                <b>{detectResult}</b>
                            </Card>
                        </Col>

                    </Row>


                </Flex>
            </Flex>





            <Modal
                title="上传图片"
                open={imgOpen}
                onOk={() => { form1.submit() }}
                confirmLoading={imgButtonLoading}
                onCancel={() => { setImgOpen(false) }
                }
            >
                    <br />
                    <div key={Math.random()}>
                        <Form
                            id="form"
                            form={form1}
                            onFinish={ImgUpload}
                            style={{ maxWidth: 600 }}
                            autoComplete="on"
                        >

                            <Form.Item name="files"
                                valuePropName="fileList"
                                getValueFromEvent={normFile}  >
                                <Dragger
                                    accept={".jpg,.png,.jpeg"}
                                    onDrop={(event) => {
                                        event.preventDefault();
                                        event.stopPropagation();
                                    }}
                                    beforeUpload={() => false}
                                    maxCount={1}
                                >
                                    <p className="ant-upload-drag-icon">
                                        <InboxOutlined />
                                    </p>
                                    <p className="ant-upload-text">点击或拖拽文件到此处</p>
                                </Dragger>
                            </Form.Item>
                        </Form>

                    </div>                
            </Modal>


            <Modal
                title="上传视频"
                open={videoOpen}
                onOk={() => { form2.submit() }}
                confirmLoading={videoButtonLoading}
                onCancel={() => { setVideoOpen(false) }
                }
            >
                <br />
                <div key={Math.random()}>
                    <Form
                        id="form2"
                        form={form2}
                        onFinish={VideoUpload}
                        style={{ maxWidth: 600 }}
                        autoComplete="on"
                    >

                        <Form.Item name="files"
                            valuePropName="fileList"
                            getValueFromEvent={normFile}  >
                            <Dragger
                                accept={".mp4,avi,.mov,.flv"}
                                onDrop={(event) => {
                                    event.preventDefault();
                                    event.stopPropagation();
                                }}
                                beforeUpload={() => false}
                                maxCount={1}
                            >
                                <p className="ant-upload-drag-icon">
                                    <InboxOutlined />
                                </p>
                                <p className="ant-upload-text">点击或拖拽文件到此处</p>
                            </Dragger>
                        </Form.Item>
                    </Form>

                </div>
            </Modal>

            {contextHolder}

        </>
    )
};

export default BugDetect;