import type { ActionType, ProColumns } from '@ant-design/pro-components';
import { ProTable } from '@ant-design/pro-components';
import {
    Button, message,
    Form, 
    GetProp,
    TableProps,
} from 'antd';
import { useEffect, useState } from 'react';
import $ from 'jquery';


import { ClassManagerSite } from '../../../global.ts';
import Skeleton1 from '../../../Module/Skeleton.tsx';

export type TableListItem = {
    key: number;
    name: string;
    studentID: string;
    class_name: string;
};


type TablePaginationConfig = Exclude<GetProp<TableProps, 'pagination'>, boolean>;
interface TableParams {
    pagination?: TablePaginationConfig;
    sortField?: string;
    sortOrder?: string;
    filters?: Parameters<GetProp<TableProps, 'onChange'>>[1];
}




const DetectRecord: React.FC = () => {

    const [dataSource, setDataSource] = useState<TableListItem[]>([]);

    const [error, setError] = useState(false);
    const [loading, setLoading] = useState(true);


    const [ClassListForm] = Form.useForm();

    const [messageApi, contextHolder] = message.useMessage();



    const [tableParams, setTableParams] = useState<TableParams>({
        pagination: {
            current: 1,
            pageSize: 20,
            total: 20
        },
    });



    // 列表结构

    const columns: ProColumns<TableListItem>[] = [
        {
            title: '文件名',
            dataIndex: 'Name',
            key: 'Name',
            render: (_) => <a>{_}</a>,
        },
        {
            title: '昆虫科目',
            dataIndex: 'BugSubject',
            key: 'BugSubject',
        },
        {
            title: 'Score',
            key: 'Score',
            dataIndex: 'Score',
        }, 
        {
            title: '检测时间',
            key: 'DetectTime',
            dataIndex: 'DetectTime',
        }
    ];

    



    function refreshForm1() {
        getMaxRecord();
        get_record_list(0);
        messageApi.success('刷新成功');
    }



    // 获取活动总数并进行表格数组填充初始化
    function getMaxRecord() {

        $.ajax({
            url: ClassManagerSite + "/Server/admin/memberList.php",
            type: 'post',
            async: false,
            data: {
                mode: 8,
                class_id: ClassListForm.getFieldValue('class_id'),
            },
            success: function (data: any) {
                var count = Number(data);
                if (isNaN(count)) return;
                //setMaxActivityCount(count);
                setTableParams({
                    ...tableParams,
                    pagination: {
                        ...tableParams.pagination,
                        total: count, // 设置总页数
                        current: 1,
                        showSizeChanger: false,
                        showQuickJumper: true
                    },
                });

                // 进行数据初始化
                const tableData: TableListItem[] = Array.from({ length: count }, () => ({
                    key: Math.random(),
                    class_name: "",
                    name: "",
                    studentID: "",
                }));

                setDataSource(tableData.slice());

            },
            error: function (data: any) {
                messageApi.error(data);
                setError(true);
            },
        });
    }

    // 处理缓存部分 防止重复加载
    const handleTableChange: TableProps['onChange'] = (pagination, filters, sorter) => {

        setTableParams({
            pagination,
            filters,
            ...sorter,
        });

        get_record_list((pagination.current! - 1) * 20);
        //}
    }

    function get_record_list(query_count: number) {

        var class_id = ClassListForm.getFieldValue('class_id');

        $.ajax({
            url: ClassManagerSite + '/Server/admin/memberList.php',
            type: 'post',
            async: false,
            data: {
                mode: 1,
                class_id: class_id,
                query_count: query_count,
            },

            success: function (data: any) {
                if (data == "not found task") {
                    setDataSource([]);
                } else {
                    const parsedData = JSON.parse(data);
                    const tableData: TableListItem[] = parsedData.map((item: any) => ({
                        key: item.account,
                        name: item.name,
                        studentID: item.account,
                        class_name: item.class_name,
                    }));

                    var dataLength = tableData.length;
                    var tempData: TableListItem[] = tableData.slice();
                    for (var i = 0; i < dataLength; i++) {
                        tempData[i + query_count] = tableData[i];
                    }

                    setDataSource(tempData.slice());
                }
            },
            error: function () {
                setError(true);
            },
        });

    }


    useEffect(() => {
        setTimeout(() => {
            //getMaxRecord();
            //get_record_list(0);
        }, 0);
        setLoading(false);
    }, []);


    return (
        <>

            {loading && <Skeleton1 />}


            {!error && !loading &&
                <ProTable<TableListItem>
                    columns={columns}
                    dataSource={dataSource}
                    pagination={tableParams.pagination}
                    onChange={handleTableChange}
                    options={{
                        reload: ((_e: React.MouseEvent<HTMLSpanElement>, _action?: ActionType) => refreshForm1())
                    }}
    

                    toolbar={
                        {
                           
                            actions: [
                                <Button
                                    key="add"
                                    type="primary"
                                >
                                    全部记录
                                </Button>,
                                <Button
                                    key="addList"
                                    type="primary"
                                >
                                    统计数量
                                </Button>,
                            ],
                        }}
                    rowKey="key"
                    search={false}
                />}

            {contextHolder}

          







        </>
    );
};

export default DetectRecord;