import React, { useEffect, useState } from 'react';
import { Button, Descriptions, DescriptionsProps, Flex, Form, Input, Modal, message } from 'antd';
import { ClassManagerSite } from '../../../global.ts';
import $ from 'jquery';
import { EyeInvisibleOutlined, EyeTwoTone } from '@ant-design/icons';
import { PasswordHash } from '../../../Module/PasswordCrypto.ts';




const UserCenter: React.FC = () => {
    
    const [userInfo, setUserInfo] = useState<null | DescriptionsProps>(null);
    const [effect, setEffect] = useState(0);
    const [open1, setOpen1] = useState(false);
    const [confirmLoading1, setConfirmLoading1] = useState(false);
    const [form1] = Form.useForm();
    const [messageApi, contextHolder] = message.useMessage();


    const formItemLayout = {
        labelCol: {
            xs: { span: 24 },
            sm: { span: 6 },
        },
        wrapperCol: {
            xs: { span: 24 },
            sm: { span: 14 },
        },
    };

    function exitLogin(){
        $.ajax({
            url: ClassManagerSite + '/Server/user/login.php',
            type: 'post',
            async: false,
            data: {
                mode: 3,
            },
            success: function(){
                window.location.href = window.location.origin + "/login.html";
            }
        });
    }


    function editPassword(values: any){

        setConfirmLoading1(true);

        $.ajax({
            url: ClassManagerSite + '/Server/user/userCenter.php',
            type: 'post',
            async: false,
            data: {
                mode: 2, 
                password: PasswordHash(values.password),
            },

            success: function (data: any) {
                if (data == "success") {
                    messageApi.info('密码修改成功!');
                    setConfirmLoading1(false);
                    setOpen1(false);
                    setTimeout(function(){
                        window.location.href = window.location.origin + "/login.html";
                    },1500);

                } else {
                    messageApi.error('密码修改失败');
                    setConfirmLoading1(false);
                    setOpen1(false);
                }

            },
            error: function (error: any) {
                messageApi.error('密码修改失败: ' + error);
                setConfirmLoading1(false);
                setOpen1(false);
            },
        });

    }


    useEffect(() => {

        if (effect > 0) {
            return;
        }
   
        setTimeout(() => {

            $.ajax({
                url: ClassManagerSite + '/Server/user/userCenter.php',
                type: 'post',
                async: true,
                data: {
                    mode: 1,
                },
                success: function (data: any) {
                    var info = JSON.parse(data);

                    setUserInfo({
                        title: '个人信息',
                        items: [
                            {
                                key: '1',
                                label: '姓名:',
                                children: info.name,
                                span: 3,
                            },
                            {
                                key: '2',
                                label: '学号',
                                children: info.account,
                               span: 3,
                            },
                            {
                                key: '3',
                                label: '班级',
                                span: 3,
                                children: info.class_name,
                            },
                            {
                                key: '4',
                                label: '权限',
                                span: 3,
                                children: info.level,
                            }
                        ]   
                    });

                },
                error: function (_data: any) {
                }
            });

        });

        setEffect(1);

    });



    return(
        <>
    <Flex title='学生信息' id="UserCenterFlex" vertical gap="small">

        {/*姓名 学号 班级 权限等级*/<>
        
                <Descriptions title="个人信息" bordered items={userInfo?.items} />

        </>}

            <Button type="primary" block onClick={()=>{setOpen1(true)}}>
                修改密码
            </Button>
            <Button type="primary" block onClick={exitLogin}>
            退出登录
        </Button>
        </Flex>

            <Modal
                title="修改密码"
                open={open1}
                onOk={() => { form1.submit() }}
                confirmLoading={confirmLoading1}
                onCancel={() => { setOpen1(false) }}
            >
                <Form {...formItemLayout} form={form1} onFinish={editPassword} style={{ maxWidth: 600 }} >
                    <Form.Item label="新密码" name="password" rules={[{ required: true, message: '请输入新密码' }]}>
                        <Input.Password maxLength={40} iconRender={(visible) => (visible ? <EyeTwoTone /> : <EyeInvisibleOutlined />)} />
                    </Form.Item>
                    <Form.Item label="重复输入密码" name="password_verify" rules={[
                        { required: true, message: '请输入相同的密码' },
                        ({ getFieldValue }) => ({
                            validator(_, value) {
                                if (!value || getFieldValue('password') === value) {
                                    return Promise.resolve()
                                }
                                return Promise.reject("两次密码输入不一致")
                            }
                        })
                    ]}
                        validateTrigger="onBlur"
                    >
                        <Input.Password maxLength={40} iconRender={(visible) => (visible ? <EyeTwoTone /> : <EyeInvisibleOutlined />)} />
                    </Form.Item>
                </Form>
            </Modal>
            {contextHolder}

        </>
)
};

export default UserCenter;