import React, { useEffect, useState } from 'react';
import {
    AlignLeftOutlined,
    BulbOutlined,
    CoffeeOutlined,
    CommentOutlined,
    FileOutlined,
    PieChartOutlined,
    QuestionCircleOutlined,
    ReadOutlined,
    SoundOutlined,
} from '@ant-design/icons';
import type { MenuProps } from 'antd';
import { Badge, Breadcrumb, Button, Divider, FloatButton, Layout, Menu, Modal, Skeleton, theme, Tooltip } from 'antd';
const { Header, Content, Footer, Sider } = Layout;
import BugDetect from './Menu/BugDetect.tsx';
import DetectRecord from './Menu/DetectRecord.tsx';
import UserCenter from '../Component/Menu/UserCenter.tsx';
import { ConfigProvider } from "antd";
import zhCN from 'antd/locale/zh_CN';
import Feature from './Menu/Feature.tsx';
import $ from 'jquery';
import { ClassManagerSite,deceteMobile,FootText, WebsiteTitle } from '../../global.ts';
import ChatLLM from './Menu/ChatLLM.tsx';
import DetectResult from './Menu/DetectResult.tsx';
import { Splitter } from 'antd';
import Title from 'antd/es/typography/Title';
import Markdown from 'react-markdown';
import remarkGfm from 'remark-gfm';
import { Base64 } from 'js-base64'
type MenuItem = Required<MenuProps>['items'][number];

function getItem(
    label: React.ReactNode,
    key: React.Key,
    icon?: React.ReactNode,
    children?: MenuItem[],
): MenuItem {
    return {
        key,
        icon,
        children,
        label,
    } as MenuItem;
}



const initialItems: MenuItem[] = [
    getItem('未读公告', 'unread', <CommentOutlined />, [
    ]),
    {type: 'divider'},
    getItem('已读公告', 'read', <CommentOutlined />, [
    ]),
];



const DashBoard: React.FC = () => {

    const [showMail, setShowMail] = useState(false);
    const [mailTitle,setMailTitle] = useState("");
    const [markdownContet, setMarkdownContent] = useState(``);


    const [mailItems, setMailItems] = useState<MenuItem[]>(initialItems);
    const [mailLoading,setMailLoading] = useState(true);



    var title_dict = ["害虫检测", "检测记录", "形态特征", "ChatLLM","识别结果","个人中心"];

    const userBoard: MenuItem[] = 
    [
            getItem('害虫检测', '0', <PieChartOutlined />),
            getItem('检测记录', '1', <AlignLeftOutlined />),
            getItem('形态特征', '2', <FileOutlined />),
            getItem('ChatLLM', '3', <CoffeeOutlined />),
            getItem('识别结果', '4', <ReadOutlined />),
            getItem('个人中心', '5', <BulbOutlined />)
    ];



    const [collapsed, setCollapsed] = useState(false);
    const [selectedContent, setSelectedContent] = useState('0');
    const [selectedTitle, setSelectedTitle] = useState('害虫检测');
    const [items, _setItems] = useState<MenuItem[]>(userBoard);
    const [isMobile, _setIsMobile] = useState(deceteMobile());
    const [unreadCount,setUnreadCount] = useState(0);

    const [effect, setEffect] = useState(0);

    //点击不同的模块切换页面
    const handleClick = (e: any) => {
        setSelectedContent(e.key);
        setSelectedTitle(title_dict[e.key]);
    }

    const {
        token: { colorBgContainer, borderRadiusLG },
    } = theme.useToken();



    function showMailModal(){
        setMailLoading(true);

        // 请求消息
        $.ajax({
            url: ClassManagerSite + "/Server/user/mail.php",
            type: 'post',
            async: true,
            data: {
                mode: 2,
            },
            success: function (data: any) {
                const parsedData = JSON.parse(data);
                // 解析json 写入数组

                const tempItems: MenuItem[] = [
                    getItem('未读消息', 'unread', <CommentOutlined />, parsedData.unread.map((mail: { mail_id: any; title: any; }) => ({
                        key: mail.mail_id,
                        label: mail.title
                    }))),
                        { type: 'divider' },
                        getItem('已读消息', 'read', <CommentOutlined />, parsedData.read.map((mail: { mail_id: any; title: any; }) => ({
                            key: mail.mail_id,
                            label: mail.title
                        }))),
                ];
                setMailLoading(false);

                setMailItems(tempItems);


            },
            error: function (_data: any) {
                return 0;
            },
        });

        setShowMail(true);
    }


    const handleClick2 = (e: any) => {
        var mail_id: string = e.key;
        var type: string = e.keyPath[1];
        setMailLoading(true);
        setMailTitle("");
        setMarkdownContent(Base64.decode(""));
        $.ajax({
            url: ClassManagerSite + "/Server/user/mail.php",
            type: 'post',
            async: true,
            data: {
                mode: 3,
                mail_id: mail_id,
                type: type
            },
            success: function (data: any) {
                const parsedData = JSON.parse(data);
                setMailTitle(parsedData.title);
                setMarkdownContent(Base64.decode(parsedData.content));
                setUnreadCount(parsedData.unread_count);
                // 同时根据返回内容修改已读数量
                setMailLoading(false);
            },
            error: function (_data: any) {
                return 0;
            },
        });



    }




    useEffect(() => {

        if (effect >0){
            return;
        }
        setTimeout(() => {

        if (navigator.userAgent.match(/Android/i) || navigator.userAgent.match(/webOS/i) || navigator.userAgent.match(/iPhone/i) || navigator.userAgent.match(/iPad/i) || navigator.userAgent.match(/iPod/i) || navigator.userAgent.match(/BlackBerry/i) || navigator.userAgent.match(/Windows Phone/i)) {
            setCollapsed(true);
        } 
        
        /*
        $.ajax({
            url: ClassManagerSite + '/Server/user/login.php',
            type: 'post',
            async: false,
            data: {
                mode: 2,
            },
            success: function (data: any) {
                if (data == "admin") {
                    setItems(adminBoard);
                    setPremissionLevel(1);
                }else if(data == "superadmin"){
                    setItems(superAdminBoard);
                    setPremissionLevel(2);
                }else if(data != "normal"){
                    window.location.href = "./login.html";
                }
            },
            error: function (_data: any) {
                window.location.href = "./login.html";
            }
        });*/

        //get_mail();
        setEffect(1);
    });
    });


    return (
        <ConfigProvider locale={zhCN}>
            <Layout style={{ minHeight: '100vh'}}>

                <Sider collapsible collapsed={collapsed} onCollapse={(value) => setCollapsed(value)} style={{ position: 'relative'}}>
                <Menu theme="dark" defaultSelectedKeys={['0']} mode="inline" items={items} onClick={handleClick} />
            </Sider>
            <Layout>

                    <Header style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between' }}>
                        <b id="user_title" onClick={() => {window.location.href = "./";}}>{WebsiteTitle}</b>
                        {
                        <Badge id="mail_button" count={unreadCount}><Button type="primary" icon={<SoundOutlined />} onClick={() => showMailModal()}>通知</Button></Badge>
                        }
                    </Header>

                <Content style={{ margin: '0 16px' }}>
                   
                    <Breadcrumb style={{ margin: '16px 0' }} items={[
                        { title: selectedTitle }
                    ]} >
                    </Breadcrumb>
                    
                    <div
                        style={{
                            padding: 24,
                            minHeight: 360,
                            background: colorBgContainer,
                            borderRadius: borderRadiusLG,
                        }}
                    >
      
                        {selectedContent == '0' && <BugDetect />}
                        {selectedContent == '1' && <DetectRecord />}
                        {selectedContent == '2' && <Feature />}
                        {selectedContent == '3' && <ChatLLM />}
                        {selectedContent == '4' && <DetectResult />}
                        {selectedContent == '5' && <UserCenter />}

                        
                    </div>
                </Content>
                <Footer style={{ textAlign: 'center' }}>
                        {FootText}
                </Footer>
                
            </Layout>
        </Layout>

 

            <Tooltip title="悬浮球" color={"#87d068"}>          
            <FloatButton.Group
                trigger="click"
                type="primary"
                style={{ insetInlineEnd: isMobile ? 10 : 50 }}
                icon={<QuestionCircleOutlined />}
            >
                    <Tooltip title="使用帮助" color={"#87d068"}>          
                <FloatButton onClick={() => { window.open(ClassManagerSite + "/Docs/") }} />
                    </Tooltip>


            </FloatButton.Group>
        </Tooltip>


            <Modal
                title="公告"
                open={showMail}
                onCancel={() => { setShowMail(false) }}
                footer={null}
                width={isMobile ?  "80%" : "50%"}
            >
                <Splitter style={{boxShadow: '0 0 10px rgba(0, 0, 0, 0.1)',height: "60vh"}}>
                  
                    <Splitter.Panel min="10%" max="50%" defaultSize="25%" resizable={false}>

                        <Menu
                            mode="inline"
                            items={mailItems}
                            onClick= {handleClick2}  
                            defaultOpenKeys={['unread','read']}                            
                        />
                    </Splitter.Panel>
                     <Splitter.Panel style={{marginLeft: '10px'}}>

                        <Title level={3}>{mailTitle}</Title>
                        <Divider />
                        <Markdown remarkPlugins={[remarkGfm]}>{markdownContet}</Markdown>

                        {mailLoading && <Skeleton />}

                    </Splitter.Panel>

                </Splitter>

            </Modal>
    


        </ConfigProvider>
    );
};

export default DashBoard;