import path, { resolve } from 'path'
import fs from 'fs'
import { defineConfig } from 'vite'
import react from '@vitejs/plugin-react-swc'
import viteCompression from 'vite-plugin-compression'
import legacy from '@vitejs/plugin-legacy'

export default defineConfig({
  build: {
    manifest: false,
    chunkSizeWarningLimit: 2000,
    minify: 'terser',
    sourcemap: false,
    rollupOptions: {
      input: {
        index: resolve(__dirname, 'index.html'),
        login: resolve(__dirname, 'login.html'),
        ChatLLM: resolve(__dirname, 'src/ChatLLM/ChatLLM.html'),
      },
      output: {
        chunkFileNames: 'static/js/[name]-[hash].js',
        entryFileNames: 'static/js/[name]-[hash].js',
        assetFileNames: 'static/assest/[name]-[hash].[ext]',
        manualChunks: {
          antd: ['antd'],
          },
      },
        },
    terserOptions: {
      compress: {
        drop_console: true,
        drop_debugger: true,
      }
    },
  },

  plugins: [
    react({plugins: [["@swc/plugin-styled-components", {}]]}),
    deleteMediaDir(),
    viteCompression({
      verbose: true,
      disable: true,
      threshold: 1024,
      algorithm: 'gzip',
      ext: '.gz',
    }),
    legacy({
      targets: ['defaults', 'not IE 11'],
    }),
  ],
});


function deleteMediaDir() {
  return {
    name: 'delete-media-dir',
    writeBundle() {
      const mediaDir = path.resolve(__dirname, 'dist', 'files');
      if (fs.existsSync(mediaDir)) {
        fs.rmSync(mediaDir, { recursive: true });
      }
    }
  };
}